#
# spec file for package rocksndiamonds
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rocksndiamonds
Version:        3.3.1.2
Release:        lp150.1.9
Summary:        Colorful Boulderdash'n'Emerald Mine'n'Sokoban'n'Stuff
License:        GPL-2.0+
Group:          Amusements/Games/Action/Arcade
Url:            http://www.artsoft.org/rocksndiamonds/
Source0:        http://www.artsoft.org/RELEASES/unix/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}-icons.tar
Source2:        %{name}.desktop
# PATCH-FIX-UPSTREAM Permissions
Patch0:         %{name}-%{version}-src_libgame_setup.c-CVE-2011-4606.patch
# PATCH-FIX-OPENSUSE bmwiedemann -- fix build-compare
Patch1:         reproducible.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(SDL_net)
#BuildRequires:  libsmpeg-devel
BuildRequires:  update-desktop-files
BuildRequires:  update-desktop-files
Requires:       %{name}-data
%if 0%{?suse_version} >= 1330
Requires(pre):  group(games)
Requires(pre):  user(games)
%else
Requires(pre):	/usr/sbin/groupadd /usr/sbin/useradd
%endif

%description
This is a nice little game with color graphics and sound for your Unix system
with color X11.  You need an 8-Bit color display or better.  It will not work
on black&white systems, and maybe not on gray scale systems.

If you know the game Boulder Dash (Commodore C64) or Emerald Mine (Amiga),
you know what Rocks'n'Diamonds is about.

%prep
%setup -q -b 1
%patch0
%patch1 -p1

# Remove not needed files
find levels -name '*.orig' -delete
rm -f %{name}

sed -i 's|-lsmpeg||' src/Makefile

%build
make %{?_smp_mflags} sdl \
    OPTIONS="%{optflags}" \
    RO_GAME_DIR=%{_datadir}/%{name} \
    RW_GAME_DIR=%{_localstatedir}/games/%{name}

%install
# install executable
install -Dm 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -Dm 0644 %{name}.1 %{buildroot}%{_mandir}/man6/%{name}.6

# install directories
mkdir -p %{buildroot}%{_datadir}/%{name}/{graphics,levels,music,sounds}
for d in graphics levels music sounds ; do
    cp -a $d %{buildroot}%{_datadir}/%{name}
done

# install icons
for i in 32 48 64 72 96 ; do
    install -Dm 0644 ../icons/%{name}_${i}x${i}.png \
            %{buildroot}/%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# install desktop file
install -Dm 0644 %{S:2} %{buildroot}%{_datadir}/applications/%{name}.desktop

install -Dm 755 -d %{buildroot}%{_localstatedir}/games/%{name}

%suse_update_desktop_file %{name}

%fdupes -s %{buildroot}%{_prefix}

%if 0%{?suse_version} < 1330
%pre
getent group games >/dev/null || groupadd -r games
getent passwd games >/dev/null || useradd -r -g games -d /var/games -s /sbin/nologin
%endif

%files
%defattr(-,root,root,-)
%doc COPYING CREDITS ChangeLog README
%{_bindir}/%{name}
%{_mandir}/man6/%{name}.6%{ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/%{name}
%attr(0775,games,games) %{_localstatedir}/games/%{name}

%changelog
* Thu Mar 30 2017 meissner@suse.com
- require system user and group games on new distros,
  useradd and groupadd on older ones.
* Thu Apr  7 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Fri Oct 10 2014 nemysis@gmx.ch
- Add because are added or deleted patches
* Wed Oct  8 2014 nemysis@gmx.ch
- Remove BuildRequires for libsmpeg-devel and add sed,
  because is unresolvable
- Use BuildRequires pkgconfig(SDL_image), pkgconfig(SDL_mixer),
  pkgconfig(SDL_net) instead of SDL_image-devel, SDL_mixer-devel,
  SDL_net-devel
- Remove PreReq for shadow and pwdutils
* Tue Oct  7 2014 nemysis@gmx.ch
- Changed .changes and used old entries from somebody else
- Update to 3.3.1.2, announce message:
  - fixed bug that prevents running the game on Mac OS X "Mavericks"
  - improved behaviour on restart after failing on a broken level set
  - Message for 3.3.1.1 update
  * added scripts directory to distribution package to enable building
    element definitions after editing artwork config source code files
  * added volume controls for sounds, loops and music to sound setup
  Most important changes since last release version 3.3.0.1:
  - added native package for Macs with intel CPUs
  - added support for compiling on 64-bit systems
  - added alternative game mode for playing with half size playfield tiles
  - added level selection screen (when clicking on main menu level number)
  - added displaying if level was played or solved on level selection screen
  - improved graphics performance for scrolling in Mac OS X version
  - improved graphics performance for native Supaplex game engine
  - improved single step mode in R'n'D, EM and SP engines
  - fixed two game engine bugs in Supaplex game engine
  - fixed displaying wrong Supaplex time (was running too fast before)
  - fixed invisible text in envelope config in level editor
- Use check for openSUSE > 12.2 for and use shadow else pwdutils
- Add PreReq for shadow (was removed pwdutils)
- Change %%fdupes
- Change Desktop entry file
- Change Summary
- Removed Contributions-1.2.0.tar.bz2 and move to new package
  rocksndiamonds-data
- Use simple sed instead of rocksndiamonds-3.3.0.1-smpeg.patch
- Use rocksndiamonds-3.3.1.2-src_libgame_setup.c-CVE-2011-4606.patch
  instead of rocksndiamonds-CVE-2011-4606.patch, upstream still has
  not patched the security problem themselves
- Add BuildRequires for libsmpeg-devel
- Use %%{name}-icons.tar instead of %%{name}.png
- Add BuildRequires for hicolor-icon-theme
- Remove BuildRequires for deprecated pwdutils
- Add Requires for %%{name}-data
- Change description
- Simplify installation handling
- Remove not needed files
* Mon Sep 23 2013 idonmez@suse.com
- Add games user/group on demand (fate#314560)
* Sat Jan 26 2013 joop.boonen@opensuse.org
- Dropped all permission scripts
* Thu Jan 24 2013 joop.boonen@opensuse.org
- run_permissions was replaced by set_permissions
  http://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros#.25set_permissions
* Fri Jan 18 2013 joop.boonen@opensuse.org
- run_permissions is obsolete, not supported in openSUSE > 12.2
- cleaned the spec file up
* Fri Jul 13 2012 meissner@suse.com
- do not create ~/.rocksndiamonds/ world writeable.
  bnc#736261 / CVE-2011-4606
* Fri Mar 23 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant sections/tags
* Sun Apr 24 2011 PVince81@opensuse.org
- updated to version 3.3.0.1
- moved game data to /usr/share instead of /usr/share/games
  according to packaging conventions
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Oct 31 2008 meissner@suse.de
- run fdupes
* Wed Mar  5 2008 anosek@suse.cz
- updated to version 3.2.4
  * lots of improvements and bugfixes. See ChangeLog for the full list
  * title messages are now also searched in graphics artwork directory;
  those found in graphics directory have precendence over those found
  in level directory -- this handles title messages stored in graphics
  directories as part of the artwork set, just like title images; this
  makes sense, as corresponding special font definitions for messages
  are usually defined in the same graphics artwork directory, and also
  because title images and title messages that are combined in a level
  set introduction should usually not be separated when the level set
  is used with a different artwork set (e.g. using "override graphics")
  * added use of hashes created from static lists (element tokens, image
  config, font tokens) to speed up lookup of configuration parameters
  * added "busy" animation when initializing program and loading artwork
  * added initialization profiling for program startup (debugging only)
  * added graphics engine directive "border.draw_masked_when_fading" that
  enables/disables drawing of border mask over screen that is just faded
  * added additional configuration directives for setup screen draw offset
  menu.draw_xoffset.SETUP[XXX] and menu.draw_yoffset.SETUP[XXX] with XXX
  in GAME, EDITOR, GRAPHICS, SOUND, ARTWORK, INPUT, SHORTCUTS_1,
  SHORTCUTS_2, CHOOSE_ARTWORK, CHOOSE_OTHER (where "CHOOSE_ARTWORK" is
  used to define draw offset on custom artwork selection screens and
  "CHOOSE_OTHER" is used on all other list style selection screens, like
  choosing game speed or screen mode for fullscreen mode)
  * added eight pure decoration graphic definitions for the game panel
  * added support for accessing native Diamond Caves II level packages
  * added game panel control to display arbitrary elements on game panel
  * added game panel control to display custom element score (globally
  unique for identical custom elements) either as value or as element
  * added ".draw_masked" and ".draw_order" to game panel control drawing
  * added displaying of gravity state (on/off) as new game panel control
  * added animation for game panel elements (similar to game elements)
  * added new pseudo game mode "PANEL" to define panel fonts and graphics
  - panel fonts now use ".PANEL" suffix instead of ".PLAYING" suffix
  - panel graphics now use ".PANEL" suffix instead of ".DOOR" suffix
  (else graphics would have to use ".PLAYING", which would be confusing)
  * added attribute ".tile_size" for element style game panel controls
  * added <space> key as additional valid key to use for confirm requester
  * improved menu fading, adding separate fading definitions for entering
  and leaving a "content" screen (in general), and optional definitions
  for the special "content" screens SCORES, EDITOR, INFO and PLAYING
  * added (currently invisible) setup option to define scroll delay value
  * added option "game.forced_scroll_delay_value" to override user choice
  of scroll delay value for certain level sets with "graphicsinfo.conf"
  * replaced setup option "scroll delay: on/off" by new setup option that
  directly allows selecting the desired scroll delay value from 0 to 8
  * added displaying of most game panel control elements (not animated)
  * added new configuration directives to display additional game engine
  values on the game control panel, like the following examples:
  - game.panel.time_hh/time_mm/time_ss	- level time in HH/MM/SS format
  - game.panel.penguins			- number of penguins to rescue
  - game.panel.level_name		- level name of current level
  * added support for preview tile sizes "1" and "2" (1x1 and 2x2 pixels)
  * added new player option "no centering when relocating" for "invisible"
  teleportations to level areas that look exactly the same, giving the
  illusion that the player did not relocate at all (this was the default
  since 3.2.3, but caused visual problems with room creation in "Zelda")
  * added new menu fading effect "melt", shamelessly stolen from "DOOM"
  * improved menu fading, adding separate fading definitions for entering
  and leaving a menu and for fading between menu and "content" screens
  * improved menu fading, adding separate fading definitions for fading
  between menu screens and fading between menu and "destination" screens
  * titlemessage_initial_x and titlemessage_x set to "[DEFAULT]" in static
  configuration (set from "[titlemessage_initial]" and "[titlemessage]")
  * fading settings of "[titlemessage_initial]" and "[titlemessage]" set
  to "[DEFAULT]" in static configuration (set from "[title_initial]" and
  "[title]")
  * improved title fading, allowing fading animation types "none", "fade"
  and "crossfade" (including cross-fading of last title to main menu)
  .......
* Sat May 19 2007 coolo@suse.de
- remove X-SuSE-translate from desktop file
* Mon Mar  5 2007 ssommer@suse.de
- BuildRequires SDL_net-devel
* Mon Feb  5 2007 anosek@suse.cz
- updated to version 3.2.3
  * bugfix release
  * some improvements on program startup performance
* Mon Sep 11 2006 anosek@suse.cz
- updated to version 3.2.2
  - instant tape reloading for the last saved tape using "quick save/load"
  - fixed bug that prevented solving levels without exit (like in Sokoban)
  - fixed bug with quick loading tapes in fullscreen with EMC game engine
  - fixed level time for EMC levels (needed for the upcoming EMC collection)
  - added key shortcut "Alt + Enter" to toggle fullscreen mode at any time
  - added support for mouse scroll wheel for all scrollbar gadgets
  - added support for horizontal mouse wheel scrolling by holding "Shift"
  - added support for single step mouse wheel scrolling by holding "Alt"
  - improved down-scaling of images for better editor and preview graphics
* Thu Aug  3 2006 anosek@suse.cz
- updated to version 3.2.0
  - finished new native game engine for Emerald Mine (Club) levels
  - added all new elements from EMC engine also to R'n'D engine
  - added selection between ECS and AGA graphics for EMC levels to setup
  - added multi-player support for EMC game engine (with up to four players)
  - added player switching (visual and quick) to R'n'D and EM game engine
  - added key shortcut settings for switching player focus to setup menu
  - added custom element actions for CE change page in level editor
  - added "CE value" and "CE score" counters for custom elements
  - added cascaded element lists to element list in level editor
  - added dynamic element list with all elements used in current level
  - added special Supaplex animations for Murphy being bored and sleeping
  - added setup option to display element token name in level editor
  - added up to five title screens for each level set to show after loading
  - added credits pages to the "credits" section that were really missing
  - lots of bugfixes and internal engine changes (see ChangeLog file)
- dropped obsolete patches
  rocksndiamonds-3.1.1-overflow.patch
  rocksndiamonds-3.1.1-userlevels.patch
* Wed Feb  1 2006 mmarek@suse.cz
- fix user levels being readonly after last update
  (userlevels.patch) (patch from upstream)
* Tue Jan 31 2006 mmarek@suse.cz
- fix buffer overflow reported by David Binderman
  [#146444] (overflow.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 mmarek@suse.cz
- added contributed levels
- added icon
* Mon Dec 19 2005 mmarek@suse.cz
- updated to 3.1.1
* Tue Apr 12 2005 mcihar@suse.cz
- fix for gcc 4
* Mon Jan 31 2005 ro@suse.de
- fix build
* Wed Aug  4 2004 mcihar@suse.cz
- update to 3.1.0
* Fri Mar 19 2004 mcihar@suse.cz
- remove *.orig files
* Wed Mar  3 2004 mcihar@suse.cz
- update to 3.0.8
* Wed Oct 29 2003 mcihar@suse.cz
- package according to permissions.secure and add %%run_permissions
- no root for build
* Tue Oct 14 2003 mcihar@suse.cz
- install in /usr/games and /usr/share/games
- update to 3.0.6 (mostly bugfixes)
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Thu Aug  7 2003 mcihar@suse.cz
- updated to 3.0.0:
  - graphics and sounds now completely and dynamically customizable
  - element animation length, speed and mode now freely configurable
  - 128 custom elements with lots of configurable element properties
  - advanced custom element settings for powerful, self-created elements
  - automatic tape playing function for game engine and level testing
  - added support for stereo WAV sound files
  - added support for background images for all menu screens
  - added some example levels showing how to create custom artwork
  - fixed Supaplex gravity tubes
  - fixed very nasty bug in SDL_image (and X11) PCX loading routine
  - fixed some very nasty bugs in bitmap zoom routine
  - fixed very nasty bug in level/artwork loading routine
- no more patches needed
- SDL version is being built now
* Thu Feb  6 2003 mcihar@suse.cz
- updated to 2.1.1:
  - sound bug (causing crashes) fixed (reported by Keith Peterston)
  - support for /dev/sound/dsp (devfs) added (thanks to Christoph Bauer)
  - added new contributed levels from the following players:
    + Alan Bond
    + Gerrit Holl
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 2.1.0:
  - graphics, sounds and music now fully configurable
  - added support for TrueColor PCX graphics files
  - added support for 16 bit WAV sound files
  - enhanced sound system (especially regarding stereo and loop sounds)
  - new structured setup menu (with sub-menues for graphics and sounds)
  - added "quick save" and "quick load" functions with shortcut key
  - added single-step playing mode (automatic pause after each step)
  - behaviour of "Escape" key in level editor now more intuitive
  - changed default slipping behaviour of gems back to 2.0.0 style;
  this is now an element property for gems in the level editor,
  although existing converted levels use the new EM gems behaviour
  - bug fixed that prevented walking through tubes when gravity on
  - added Boulder Dash style "snap-pushing" (thanks to Achim Hrtel)
  - fixed memory leak in image loading code
  - fixed some "solid" elements that were accidentally destructible
  - fixed some tape stuff
  - added new contributed levels and graphics from players
* Sun Aug  4 2002 ro@suse.de
- group name changed "game" -> "games"
* Tue Jun 11 2002 mcihar@suse.cz
- updated to 2.0.1
  - bug in explosion code fixed that broke level 24 of "Baby Ghost Mine"
  - several Supaplex emulation bugs fixed (thanks to Mihail Milushev):
  - behaviour of robots adjusted to make them less aggressive
  - bug when selecting default level series fixed
  - new IFF style file format for level and tape files
  - bug in storing amoeba content fixed
  - nasty tape bugs fixed (completely reworked tape stuff)
  - file permissions when saving files and creating directories changed
  - some small sound bugs fixed
  - added new contributed levels
* Thu Jan 10 2002 cihlar@suse.cz
- use %%{_lib}
* Wed Sep 19 2001 ro@suse.de
- unified changelog
* Mon Mar 12 2001 cihlar@suse.cz
- fixed to compile on axp
* Thu Mar  8 2001 cihlar@suse.cz
- update to version 2.0.0
* Thu Feb  8 2001 cihlar@suse.cz
- fixed to compile
* Fri Dec  8 2000 cihlar@suse.cz
- added missing levels
* Fri Dec  1 2000 cihlar@suse.cz
- again fixed file permissions
* Wed Nov 15 2000 cihlar@suse.cz
- renamed rockdiam -> rocksndiamonds
- clean up spec file
- fixed file permissions
* Tue Apr 18 2000 cihlar@suse.cz
- upgrade to version 1.4.0
- added BuildRoot
* Sun Mar  5 2000 olh@suse.de
- move manpages
* Mon Jan 31 2000 uli@suse.de
- fixed misuse of va_arg macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Mar 12 1999 uli@suse.de
- update 0.9b -> 1.3.0
- eliminated Makefile.Linux
* Mon Oct 20 1997 hf@suse.de
- ready for autobuild
* Mon Jun  9 1997 hf@suse.de
- Changing the permissions for the highscorefiles.
* Fri Jun  6 1997 hf@suse.de
- Changing the permissions for the highscoredirectory.
* Mon May  5 1997 hf@suse.de
- The binary rocksndiamonds has the sgid game
  for edit the highscore and name files.
* Thu Mar  6 1997 hf@suse.de
- Version 0.9
  Anpassungen im Makefile, zustzliche defines angelegt
